package com.bonus.material.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.common.security.annotation.InnerAuth;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.common.biz.domain.BmStorageLog;
import com.bonus.material.basic.service.IBmStorageLogService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 库存日志Controller
 * 
 * @author xsheng
 */
@Api(tags = "库存日志接口")
@RestController
@RequestMapping("/bm_storage_log")
public class BmStorageLogController extends BaseController
{
    @Autowired
    private IBmStorageLogService bmStorageLogService;

    /**
     * 查询库存日志列表
     */
    @ApiOperation(value = "查询库存日志列表")
    @RequiresPermissions("stock:log:list")
    @GetMapping("/list")
    public TableDataInfo list(BmStorageLog bmStorageLog)
    {
        startPage();
        List<BmStorageLog> list = bmStorageLogService.selectBmStorageLogList(bmStorageLog);
        return getDataTable(list);
    }

    /**
     * 导出库存日志列表
     */
    @ApiOperation(value = "导出库存日志列表")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:log:export")
    @SysLog(title = "库存日志", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出库存日志")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmStorageLog bmStorageLog)
    {
        List<BmStorageLog> list = bmStorageLogService.selectBmStorageLogList(bmStorageLog);
        ExcelUtil<BmStorageLog> util = new ExcelUtil<BmStorageLog>(BmStorageLog.class);
        util.exportExcel(response, list, "库存日志数据");
    }

    /**
     * 获取库存日志详细信息
     */
    @ApiOperation(value = "获取库存日志详细信息")
    @RequiresPermissions("basic:log:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bmStorageLogService.selectBmStorageLogById(id));
    }

    /**
     * 新增库存日志
     */
    @ApiOperation(value = "新增库存日志")
    @SysLog(title = "库存日志", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增库存日志")
    @PostMapping("/add")
    public AjaxResult insert(@RequestBody BmStorageLog bmStorageLog)
    {
        return toAjax(bmStorageLogService.insertBmStorageLog(bmStorageLog));
    }

    /**
     * 修改库存日志
     */
    @ApiOperation(value = "修改库存日志")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:log:edit")
    @SysLog(title = "库存日志", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改库存日志")
    @PutMapping
    public AjaxResult edit(@RequestBody BmStorageLog bmStorageLog)
    {
        return toAjax(bmStorageLogService.updateBmStorageLog(bmStorageLog));
    }

    /**
     * 删除库存日志
     */
    @ApiOperation(value = "删除库存日志")
    @PreventRepeatSubmit
    @RequiresPermissions("basic:log:remove")
    @SysLog(title = "库存日志", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除库存日志")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bmStorageLogService.deleteBmStorageLogByIds(ids));
    }

    @InnerAuth
    @PostMapping
    public AjaxResult batchInsert(@RequestBody List<BmStorageLog> bmStorageLogList) {
        return toAjax(bmStorageLogService.batchInsert(bmStorageLogList));
    }
}
